@@ -1,4 +1,11 @@
+"""Label module.
+
+For more information on the underlying Qt5 object see
+[QLabel](https://doc.qt.io/qt-5/qlabel.html).
+"""
+
 from .qutie import QtWidgets
+from .qutie import TextFormat
 
 from .frame import Frame
 from .pixmap import Pixmap
@@ -19,9 +26,14 @@ class Label(Frame):
 
     QtClass = QtWidgets.QLabel
 
+    link_activated = None
+    link_hovered = None
+
     def __init__(self, text=None, *, indent=None, margin=None, pixmap=None,
-                 word_wrap=None, **kwargs):
+                 text_format=None, word_wrap=None, link_activated=None,
+                 link_hovered=None, **kwargs):
         super().__init__(**kwargs)
+        # Properties
         if text is not None:
             self.text = text
         if indent is not None:
@@ -30,8 +42,16 @@ class Label(Frame):
             self.margin = margin
         if pixmap is not None:
             self.pixmap = pixmap
+        if text_format is not None:
+            self.text_format = text_format
         if word_wrap is not None:
             self.word_wrap = word_wrap
+        # Callbacks
+        self.link_activated = link_activated
+        self.link_hovered = link_hovered
+        # Connect signals
+        self.qt.linkActivated.connect(lambda link: self.emit(self.link_activated, link))
+        self.qt.linkHovered.connect(lambda link: self.emit(self.link_hovered, link))
 
     @property
     def text(self):
@@ -70,6 +90,16 @@ class Label(Frame):
             value = Pixmap(value)
         self.qt.setPixmap(value.qt)
 
+    @property
+    @TextFormat.getter
+    def text_format(self):
+        return self.qt.textFormat()
+
+    @text_format.setter
+    @TextFormat.setter
+    def text_format(self, value):
+        self.qt.setTextFormat(value)
+
     @property
     def word_wrap(self):
         """Enable automatic word wrap."""
