@@ -1,3 +1,5 @@
+"""This module provides backward compatibility for qutie < 1.6.0"""
+
 from PyQt5 import QtCore
 from PyQt5 import QtGui
 from PyQt5 import QtWidgets
@@ -12,8 +14,6 @@ __all__ = [
 def bind(qt):
     """Decorator used to bind custom events on a Qt base class."""
     def bind(cls):
-        class QtClass(qt):
-            eventEmitted = QtCore.pyqtSignal(str, object, object)
-        cls.QtClass = QtClass
+        cls.QtClass = qt
         return cls
     return bind
