@@ -1,6 +1,7 @@
-"""Stack widget.
+"""Stack module.
 
-For more information on the underlying Qt5 object see [QStackedWidget](https://doc.qt.io/qt-5/qstackedwidget.html).
+For more information on the underlying Qt5 object see
+[QStackedWidget](https://doc.qt.io/qt-5/qstackedwidget.html).
 """
 
 from .qutie import QtCore
@@ -14,59 +15,59 @@ class Stack(BaseWidget):
 
     QtClass = QtWidgets.QStackedWidget
 
-    def __init__(self, *items, changed=None, **kwargs):
+    changed = None
+    removed = None
+
+    def __init__(self, *items, changed=None, removed=None, **kwargs):
         super().__init__(**kwargs)
+        # Properties
         for item in items:
             self.append(item)
+        # Callbacks
         self.changed = changed
+        self.removed = removed
         # Connect signals
-        self.qt.currentChanged.connect(self.__handle_changed)
+        self.qt.currentChanged.connect(lambda index: self.emit(self.changed, index))
+        self.qt.widgetRemoved.connect(lambda index: self.emit(self.removed, index))
 
-    @property
-    def items(self):
-        return list(self)
-
-    def append(self, item):
+    def append(self, item) -> None:
         self.qt.addWidget(item.qt)
 
-    def insert(self, index, item):
+    def insert(self, index: int, item) -> None:
         if index < 0:
             index = max(0, len(self) + index)
         self.qt.insertWidget(index, item.qt)
 
+    def extend(self, iterable) -> None:
+        """Extend list by appending values from the iterable."""
+        for item in iterable:
+            self.append(item)
+
     def remove(self, item):
+        self.index(item)
         self.qt.removeWidget(item.qt)
 
+    def clear(self):
+        while len(self):
+            self.remove(self[0])
+
     @property
     def current(self):
-        item = self.qt.currentIndex()
-        if item is not None:
-            return item.reflection()
-        return item
+        index = self.qt.currentIndex()
+        if index < 0:
+            return None
+        return self[index]
 
     @current.setter
     def current(self, item):
-        index = self.qt.indexOf(item.qt)
-        self.qt.setCurrentIndex(index)
+        self.qt.setCurrentIndex(self.index(item))
 
-    def index(self, item):
+    def index(self, item) -> int:
         index = self.qt.indexOf(item.qt)
         if index < 0:
             raise ValueError("item not in stack")
         return index
 
-    @property
-    def changed(self):
-        return self.__changed
-
-    @changed.setter
-    def changed(self, changed):
-        self.__changed = changed
-
-    def __handle_changed(self, index):
-        if callable(self.changed):
-            self.changed(index)
-
     def __getitem__(self, key):
         item = self.qt.widget(key)
         if not item:
