@@ -1,17 +1,20 @@
-"""Timer.
+"""Timer module.
 
-For more information on the underlying Qt5 object see [QTimer](https://doc.qt.io/qt-5/qtimer.html).
+For more information on the underlying Qt5 object see
+[QTimer](https://doc.qt.io/qt-5/qtimer.html).
 """
 
 from .qutie import QtCore
-from .qutie import Qutie
+
+from .object import Object
 
 __all__ = ['Timer', 'single_shot']
 
-def single_shot(interval, timeout):
+def single_shot(interval: float, timeout) -> None:
+    """Single shot timer function."""
     QtCore.QTimer.singleShot(interval * 1e3, timeout)
 
-class Timer(Qutie):
+class Timer(Object):
     """Timer.
 
     >>> timer = Timer(interval=1.0, timeout=lambda: print("Done!"))
@@ -29,13 +32,15 @@ class Timer(Qutie):
     def __init__(self, *, interval=0, single_shot=False, timer_type=None,
                  timeout=None, **kwargs):
         super().__init__(**kwargs)
+        # Properties
         self.interval = interval
         self.single_shot = single_shot
         if timer_type is not None:
             self.timer_type = timer_type
+        # Callback
         self.timeout = timeout
         # Connect signals
-        self.qt.timeout.connect(self.__handle_timeout)
+        self.qt.timeout.connect(lambda: self.emit(self.timeout))
 
     @property
     def interval(self):
@@ -63,24 +68,11 @@ class Timer(Qutie):
         self.qt.setTimerType(self.QtTimerTypes[value])
 
     @property
-    def timeout(self):
-        """Event called on timer timeout."""
-        return self.__timeout
-
-    @timeout.setter
-    def timeout(self, value):
-        self.__timeout = value
-
-    def __handle_timeout(self):
-        if callable(self.timeout):
-            self.timeout()
-
-    @property
-    def active(self):
+    def active(self) -> bool:
         return self.qt.isActive()
 
     @property
-    def remaining_time(self):
+    def remaining_time(self) -> float:
         value = self.qt.remainingTime()
         if value < 0:
             return 0.
@@ -90,11 +82,11 @@ class Timer(Qutie):
     def timer_id(self):
         return self.qt.itmerId()
 
-    def start(self, interval=None):
+    def start(self, interval=None) -> None:
         if interval is None:
             self.qt.start()
         else:
             self.qt.start(interval * 1e3)
 
-    def stop(self):
+    def stop(self) -> None:
         self.qt.stop()
